@@ -21,7 +21,7 @@ from fastapi.params import Depends
 from fastapi import FastAPI, Body
 from fastapi.dependencies.utils import solve_dependencies, get_dependant, get_flat_dependant, \
     get_parameterless_sub_dependant
-from fastapi.exceptions import RequestValidationError
+from fastapi.exceptions import RequestValidationError, HTTPException
 from fastapi.routing import APIRoute, APIRouter, serialize_response
 from starlette.background import BackgroundTasks
 from starlette.concurrency import run_in_threadpool
@@ -1128,6 +1128,8 @@ class Entrypoint(APIRouter):
             resp = await self.handle_exception(exc)
         except BaseError as error:
             resp = error.get_resp()
+        except HTTPException:
+            raise
         except Exception as exc:
             logger.exception(str(exc), exc_info=exc)
             resp = InternalError().get_resp()
